Crate cw3[−][src]
Structs
| Cw3Contract | Cw3Contract is a wrapper around Addr that provides a lot of helpers for working with this. |
| ProposalListResponse | |
| ProposalResponse | Note, if you are storing custom messages in the proposal, the querier needs to know what possible custom message types those are in order to parse the response |
| VoteInfo | Returns the vote (opinion as well as weight counted) as well as the address of the voter who submitted it |
| VoteListResponse | |
| VoteResponse | |
| VoterDetail | |
| VoterListResponse | |
| VoterResponse |
Enums
| Cw3ExecuteMsg | |
| Cw3QueryMsg | |
| Status | |
| ThresholdResponse | This defines the different ways tallies can happen. Every contract should support a subset of these, ideally all. |
| Vote |